//
//  ReusableGridViewCellExampleViewController.m
//  ReusableGridViewCellExample
//
//  Created by Jaymie Strecker at Kosada Incorporated on 10/21/11.
//
//  This is free and unencumbered software released into the public domain.
//  
//  Anyone is free to copy, modify, publish, use, compile, sell, or
//  distribute this software, either in source code form or as a compiled
//  binary, for any purpose, commercial or non-commercial, and by any
//  means.
//  
//  In jurisdictions that recognize copyright laws, the author or authors
//  of this software dedicate any and all copyright interest in the
//  software to the public domain. We make this dedication for the benefit
//  of the public at large and to the detriment of our heirs and
//  successors. We intend this dedication to be an overt act of
//  relinquishment in perpetuity of all present and future rights to this
//  software under copyright law.
//  
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
//  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
//  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
//  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR
//  OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
//  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
//  OTHER DEALINGS IN THE SOFTWARE.
//  
//  For more information, please refer to <http://unlicense.org/>

#import "ReusableGridViewCellExampleViewController.h"


@interface ReusableGridViewCellExampleViewController ()
@property (nonatomic, retain) NSArray *names;
@end


@implementation ReusableGridViewCellExampleViewController

@synthesize gridView, gridViewCellContent, names;

- (void)viewDidLoad
{
	// http://www.chinesenames.org/chinese-name/girls.htm
	// http://www.chinesenames.org/chinese-name/boys.htm
	self.names = [NSArray arrayWithObjects:
				  @"Bao", 
				  @"Cai", 
				  @"Cheng", 
				  @"Feng", 
				  @"Hong", 
				  @"Hu", 
				  @"Hui", 
				  @"Jie", 
				  @"Juan", 
				  @"Liang", 
				  @"Peng", 
				  @"Qiao", 
				  @"Qing", 
				  @"Shan", 
				  @"Tian", 
				  @"Wen", 
				  @"Xue",
				  @"Yi", 
				  nil];
	
	gridView.dataSource = self;
	[gridView reloadData];
}

- (NSUInteger)numberOfItemsInGridView:(AQGridView *)aGridView
{
    return [names count];
}

- (AQGridViewCell *)gridView:(AQGridView *)aGridView cellForItemAtIndex:(NSUInteger)index
{
	static NSString *CellIdentifier = @"ReusableGridViewCell";
	
	AQGridViewCell *cell = (AQGridViewCell *)[gridView dequeueReusableCellWithIdentifier:CellIdentifier];
	if (cell == nil)
	{
		[[NSBundle mainBundle] loadNibNamed:@"ReusableGridViewCell" owner:self options:nil];

		cell = [[[AQGridViewCell alloc] initWithFrame:gridViewCellContent.frame
									  reuseIdentifier:CellIdentifier] autorelease];
		[cell.contentView addSubview:gridViewCellContent];
		
		cell.selectionStyle = AQGridViewCellSelectionStyleNone;
	}
	
	ReusableGridViewCell *content = (ReusableGridViewCell *)[cell.contentView viewWithTag:1];
	NSString *name = [names objectAtIndex:index];
	NSString *imageName = [[name lowercaseString] stringByAppendingString:@".gif"];
	content.imageView.image = [UIImage imageNamed:imageName];
	content.textLabel.text = name;

	return cell;
}

- (CGSize)portraitGridCellSizeForGridView:(AQGridView *)aGridView
{
	[[NSBundle mainBundle] loadNibNamed:@"ReusableGridViewCell" owner:self options:nil];
	return gridViewCellContent.frame.size;
}

- (void)dealloc
{
	[gridView release];
	[gridViewCellContent release];
	[names release];
    [super dealloc];
}

@end
